"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.AggregateRoot = void 0;
class AggregateRoot {
    constructor() {
        this._domainEvents = [];
    }
    get domainEvents() {
        return this._domainEvents;
    }
    addEvent(domainEvent) {
        this._domainEvents.push(domainEvent);
    }
    clearEvents() {
        this._domainEvents = [];
    }
    async publishEvents(notifier) {
        await Promise.all(this.domainEvents.map(async (event) => {
            return notifier.notifyEvent(event.name, event.payload);
        }));
        this.clearEvents();
        for (const attr in this) {
            const attribute = this[attr];
            if (attribute instanceof AggregateRoot) {
                await attribute.publishEvents(notifier);
            }
            else if (attribute instanceof Array) {
                const prop = attribute;
                for (const nestedAttribute of prop) {
                    if (nestedAttribute instanceof AggregateRoot) {
                        await nestedAttribute.publishEvents(notifier);
                    }
                }
            }
        }
    }
}
exports.AggregateRoot = AggregateRoot;
//# sourceMappingURL=aggregate-root.js.map